from lxml import etree
from datetime import datetime
import re

#file paths 
file_path = '/.../BaptismalRegistriesOfTheParishofAldoar_OriginalEAD.xml'
new_file_path = '/.../BaptismalRegistriesOfTheParishOfAldoar_EnrichedXML.xml'

#months dictionary for date normalization
MONTHS = {
    'janeiro': 1, 'fevereiro': 2, 'março': 3, 'abril': 4,
    'maio': 5, 'junho': 6, 'julho': 7, 'agosto': 8,
    'setembro': 9, 'outubro': 10, 'novembro': 11, 'dezembro': 12
}

def parse_date(date_str):
    """Converti una stringa di data in formato yyyy-MM-dd'T'HH:mm:ss."""
    date_str = date_str.strip().lower()
    
    if date_str in ["não mencionado", "", None]:
        return date_str, "não mencionado"
    
    # Extract date pattern from input string
    date_pattern = r'\b(\d{4}-\d{2}-\d{2})\b'
    match = re.search(date_pattern, date_str)
    if match:
        date_str = match.group(1)
    
    # Caso formato "yyyy-MM-dd"
    try:
        parts = date_str.split('-')
        year = int(parts[0])
        month = int(parts[1])
        day = int(parts[2])
        date_obj = datetime(year, month, day)
        formatted_date = date_obj.strftime('%Y-%m-%dT%H:%M:%S')
        return date_str, formatted_date
    except (ValueError, IndexError):
        pass
    
    # Caso formato "dd-MM-yyyy" o "dd/MM/yyyy"
    try:
        date_obj = datetime.strptime(date_str, '%d-%m-%Y')
        formatted_date = date_obj.strftime('%Y-%m-%dT%H:%M:%S')
        return date_str, formatted_date
    except ValueError:
        pass
    
    try:
        date_obj = datetime.strptime(date_str, '%d/%m/%Y')
        formatted_date = date_obj.strftime('%Y-%m-%dT%H:%M:%S')
        return date_str, formatted_date
    except ValueError:
        pass

    #To handle the date format "dd de MMMM de yyyy"
    try:
        parts = date_str.split(' de ')
        day = int(parts[0])
        month_str = parts[1]
        year = int(parts[2])
        month = MONTHS.get(month_str.lower())
        if month is None:
            raise ValueError("Mese non riconosciuto")
        date_obj = datetime(year, month, day)
        formatted_date = date_obj.strftime('%Y-%m-%dT%H:%M:%S')
        return date_str, formatted_date
    except (ValueError, IndexError) as e:
        print(f"Errore nella conversione della data '{date_str}': {e}")
        return date_str, "not definable"

try:
    # Read the original XML file contents
    with open(file_path, 'rb') as file:
        xml_content = file.read()

    # Convert contents into strings
    xml_content_str = xml_content.decode('utf-8')

    # Analyze contents
    root = etree.fromstring(xml_content_str.encode('utf-8'))

    # Find the XML <c> elements at item level
    c_elements = root.findall('.//c[@level="item"]')
    print(f'Numero di elementi <c> trovati: {len(c_elements)}')

    # Create a list to save extracted data
    data = []

    # List of common second names created to improve the split results between names and surnames
    father_name_list = ["antónio", "joão", "francisco", "manuel", "jorge", "lourenço", "julio", "luis", "joaquim", "josé", "maria", "batista", "luís", "miguel", "alberto", "caetano", "tomás"]
    mother_name_list = ["maria", "joaquina", "rosa", "ana", "margarida", "josefa", "francisca", "antónia"]

    # Iteration on each <c> elements
    for c in c_elements:
        # Variables inizialization
        physloc_text = ""
        unitid_text = ""
        title_text = ""
        child = ""
        scopecontent_text = ""
        birth_date = ""
        formatted_birth_date = ""
        parents = ""
        father = "incógnito"
        mother = "incógnita"
        grandparents_father = "none"
        grandfather_f = "none"
        grandmother_f = "none"
        grandparents_mother = "none"
        grandfather_m = "none"
        grandmother_m = "none"
        padrini = "none"
        godfather_1 = "none"
        godfather_2 = "none"
        mother_last_name = "none"
        father_last_name = "none"

        # Find the <physloc> element in the current <c>
        physloc = c.find('.//physloc')
        if physloc is not None and physloc.text is not None:
            physloc_text = physloc.text.strip()

        # Find all <scopecontent> elements in the current <c>
        scopecontents = c.find('.//scopecontent')
        title = c.find('.//unittitle')
        unitid = c.find('.//unitid')

        if unitid is not None and unitid.text is not None:
            unitid_text = unitid.text.strip()
        if title is not None and title.text is not None:
            title_text = title.text.strip()

        # split the <scopecontent> for data extraction
        if scopecontents is not None and scopecontents.text is not None:
            scopecontent_text = scopecontents.xpath('substring-before(., "Data")').strip()
            birth_date = scopecontents.xpath('substring-after(., "Data de nascimento:")').strip()
            original_birth_date, formatted_birth_date = parse_date(birth_date)
            if formatted_birth_date == "não mencionado":
                formatted_birth_date = "none"

            if "Pais:" in scopecontent_text:
                parents = scopecontent_text.split("Pais:", 1)[-1].split("\n", 1)[0].strip()
                if "incógnitos" in parents.lower():
                    father = "incógnito"
                    mother = "incógnita"
                else:
                    if " e " in parents:
                        father, mother = parents.split(" e ", 1)
                        father, mother = father.strip(), mother.strip()
                        if mother.startswith("de "):
                            mother = mother[3:].strip()
                        if "incógnito" in father.lower():
                            father = "incógnito"

            if "paternos:" in scopecontent_text:
                grandparents_father = scopecontent_text.split("paternos:", 1)[-1].split("\n", 1)[0].strip()
                if " e " in grandparents_father:
                    grandfather_f, grandmother_f = grandparents_father.split(" e ", 1)
                    grandfather_f, grandmother_f = grandfather_f.strip(), grandmother_f.strip()

            if "maternos:" in scopecontent_text:
                grandparents_mother = scopecontent_text.split("maternos:", 1)[-1].split("\n", 1)[0].strip()
                if " e " in grandparents_mother:
                    grandfather_m, grandmother_m = grandparents_mother.split(" e ", 1)
                    grandfather_m, grandmother_m = grandfather_m.strip(), grandmother_m.strip()

            if "Padrinhos:" in scopecontent_text:
                padrini = scopecontent_text.split("Padrinhos:", 1)[-1].split("\n", 1)[0].strip()
                if " e " in padrini:
                    godfather_1, godfather_2 = padrini.split(" e ", 1)
                    godfather_1, godfather_2 = godfather_1.strip(), godfather_2.strip()

            # Function to extract surnames for word list
            def extract_last_name(parts, name_list, exclude_words=[]):
                filtered_parts = [word for word in parts if word.lower() not in exclude_words]
                if len(filtered_parts) >= 2:
                    if len(filtered_parts) >= 3 and filtered_parts[1].lower() in name_list:
                        return " ".join(filtered_parts[2:])  # get all words besides the first two
                    elif len(filtered_parts) == 2 and filtered_parts[1].lower() in name_list:
                        return ""
                    else:
                        return " ".join(filtered_parts[1:])  # get all words besides the first
                return ""

            # Function to combine the father's name
            def combine_father_last_name(father_parts, name_list):
                if len(father_parts) >= 2:
                    if len(father_parts) >= 3 and father_parts[1].lower() in name_list:
                        return " ".join(father_parts[2:])  # get all words besides the first two
                    elif len(father_parts) == 2 and father_parts[1].lower() in name_list:
                        return ""
                    return " ".join(father_parts[1:])   # get all words besides the first
                return ""

            # Extract the name of the child
            child_base = title_text.rsplit(" de ", 1)[-1].strip()

            # Split parents names
            father_parts = father.split()
            mother_parts = mother.split()

            # Extract parents surnames
            father_last_name = extract_last_name(father_parts, father_name_list)
            mother_last_name = extract_last_name(mother_parts, mother_name_list, exclude_words=["solteira", "incógnita"])
            
            # Combined father's name
            combined_father_last_name = combine_father_last_name(father_parts, father_name_list)

            # Define the child full name 
            if "solteiro" in father.lower():
                if "solteira" in mother.lower():
                    child = child_base
                else:
                    child = f"{child_base} {mother_last_name}" if mother_last_name else child_base
            elif "incógnito" in father.lower():
                mother_lower = mother.lower()
                if "escrava" in mother_lower or (len(mother_parts) == 2 and mother_parts[1].lower() in mother_name_list):
                    child = child_base
                else:
                    child = f"{child_base} {mother_last_name}" if mother_last_name else child_base
            elif "desconhecidos" in parents or "incógnitos" in parents:
                    child = child_base
            elif combined_father_last_name == "":
                if mother_last_name != "":
                        child = f"{child_base} {mother_last_name}" if mother_last_name else child_base
                else:
                    child = child_base
            else:
                child = f"{child_base} {combined_father_last_name}" if combined_father_last_name else child_base

            # Add found elements to the list
            data.append({
                'physloc': physloc_text,
                'unitid': unitid_text,
                'child': child,
                'birth_date': birth_date,
                'formatted_birth_date': formatted_birth_date,
                'father': father,
                'mother': mother,
                'grandfather_f': grandfather_f,
                'grandmother_f': grandmother_f,
                'grandfather_m': grandfather_m,
                'grandmother_m': grandmother_m,
                'godfather_1': godfather_1,
                'godfather_2': godfather_2
            })
    
    # Iteration for file update
    all_c_elements = root.findall('.//c')

    # Iteration on each <c> element
    for elem in all_c_elements:
        unitid_elem = elem.find('.//unitid')
        if unitid_elem is not None:
            # Add <id>
            elem.set('id', unitid_elem.text)

    for entry in data:
        physloc_text = entry['physloc']
        unitid_text = entry['unitid']
        
        # Find every <c> element accorging to <physloc> and <unitid> values
        for elem in c_elements:
            physloc_elem = elem.find('.//physloc')
            unitid_elem = elem.find('.//unitid')
            if physloc_elem is not None and unitid_elem is not None:
                if physloc_elem.text == physloc_text and unitid_elem.text == unitid_text:
                    # create new tags and add them to the current <c> element
                    for key, value in entry.items():
                        if key not in ['physloc', 'unitid'] and value != "none": 
                            # Verify the existance of the tag
                            existing_elem = elem.find(key)
                            if existing_elem is not None:
                                # If it exist already, overwrite it
                                existing_elem.text = str(value)
                            else:
                                # Otherwise, create a new element
                                new_elem = etree.SubElement(elem, key)
                                new_elem.text = str(value)  # Convert the value in string if necessary


    
    etree.indent(root, space="  ")

    # Write the new XML file
    tree = etree.ElementTree(root)
    tree.write(new_file_path, encoding='utf-8', xml_declaration=True, pretty_print=True)
    print("File XML successfully modified.")

except Exception as e:
    print(f"Errore: {e}")
