<?xml version="1.0" encoding="UTF-8"?>
<!-- 
	The main stylesheet to convert Archives Nationales EAD files to RiC-O, 
	provided by the National Archives of France in the Context of the RiC-O converter tool, edited in order to convert
	XML files of the National Archive of Portugal in RiC-O.
 -->
<xsl:stylesheet version="2.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:xlink="http://www.w3.org/1999/xlink"
	xmlns:rico="https://www.ica.org/standards/RiC/ontology#"
	xmlns:ead2rico="http://data.archives-nationales.culture.gouv.fr/ead2rico/"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:isni="https://isni.org/ontology#"
	xmlns:owl="http://www.w3.org/2002/07/owl#"
	xmlns:html="http://www.w3.org/1999/xhtml"
	xmlns:skos="http://www.w3.org/2004/02/skos/core#"
	exclude-result-prefixes="ead2rico xlink xs xsi xsl skos"
>
	<!-- Import URI stylesheet -->
	<xsl:import href="ead2rico-uris.xslt" />
	<!-- Import builtins stylesheet -->
	<xsl:import href="ead2rico-builtins.xslt" />

	<xsl:output indent="yes" method="xml" />

	<!--  Global variable for faId to reference it in functions -->
	<xsl:variable name="faId" select="'PT-ADPRT-PRQ-PPRT01'" />
	
	<xsl:template match="/">
		<rdf:RDF>
			<!-- Sets xml:base on root this way, so that compilation of XSLT does not fail because it is not a URI -->
			<xsl:attribute name="xml:base" select="$BASE_URI" />
			<xsl:apply-templates />
		</rdf:RDF>
	</xsl:template>
	
	<xsl:template match="ead">
		<!-- Process header -->
		<xsl:apply-templates select="eadheader" />
		
	    <!-- Then process archdesc -->
		<xsl:apply-templates select="archdesc" />
	</xsl:template>
	
	<!-- ***** eadheader processing ***** -->
	
	<xsl:template match="eadheader">
		<xsl:variable name="InstantiationId" select="concat($faId, '-i1')" />
		
		<!--  FindingAid object -->
		<rico:Record rdf:about="{ead2rico:URI-FindingAid($faId)}">	
			<rico:hasDocumentaryFormType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/documentaryFormTypes#FindingAid" />
	
			<!--  Turn the attributes into isRegulatedBy pointing to Rules -->
			<xsl:if test="@countryencoding = 'iso3166-1'">
				<rico:isOrWasRegulatedBy rdf:resource="rule/rl005"/>
			</xsl:if>
			<xsl:if test="@dateencoding = 'iso8601'">
				<rico:isOrWasRegulatedBy rdf:resource="rule/rl004"/>
			</xsl:if>
			<xsl:if test="@langencoding = 'iso639-2b'">
				<rico:isOrWasRegulatedBy rdf:resource="rule/rl006"/>
			</xsl:if>
			<xsl:if test="@repositoryencoding = 'iso15511'">
				<rico:isOrWasRegulatedBy rdf:resource="rule/rl007"/>
			</xsl:if>
			<xsl:if test="@scriptencoding = 'iso15924'">
				<rico:isOrWasRegulatedBy rdf:resource="rule/rl008"/>
			</xsl:if>
			<!-- Reference to ISAD(G), to be changed if you don't follow the ISAD(G) model -->
			<rico:isOrWasRegulatedBy rdf:resource="rule/rl009"/>
	
			<!-- process child elements in mode 'findingaid' -->
			<xsl:apply-templates mode="findingaid" />
	
			<!-- Generates an Instantiation of the FindingAid in a child element -->
			<xsl:apply-templates select="../archdesc" mode="reference" />
			<rico:hasInstantiation>
				<!--  FindingAid Instantiation -->
			    <rico:Instantiation rdf:about="{ead2rico:URI-Instantiation($InstantiationId)}">
			      <!-- link back to parent URI -->
			      <rico:isInstantiationOf rdf:resource="{ead2rico:URI-FindingAid($faId)}"/>
			      <!-- process child elements again but this time in mode 'instantiation' -->
			      <xsl:apply-templates mode="instantiation" />
			      <!-- Always insert this regulatedBy on FindingAid's Instantiation in case of AN -->
			      <rico:isOrWasRegulatedBy rdf:resource="rule/rl010"/>
			      <dc:format xml:lang="en">text/xml</dc:format>
			    </rico:Instantiation>
			</rico:hasInstantiation>
		</rico:Record>
		
	</xsl:template>

	
	<xsl:template match="filedesc" mode="findingaid">
		<!-- Don't process editionstmt since it is processed in rico:history below -->
		<!-- titlestmt/author is still processed since it generates a createdBy with the AUTOR_URI -->
		<xsl:apply-templates select="* except editionstmt" mode="#current" />
	</xsl:template>	

	<!-- For Instantiation just navigate down, don't generate rico:history -->
	<xsl:template match="filedesc" mode="instantiation">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	
	<xsl:template match="titlestmt" mode="#all">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	<xsl:template match="titleproper[normalize-space(.)]" mode="findingaid instantiation">
		<rico:title xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(if(../subtitle) then concat(., ' : ', ../subtitle) else .)" /></rico:title>
		<rdfs:label xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(if(../subtitle) then concat(., ' : ', ../subtitle) else .)" /></rdfs:label>
	</xsl:template>
	
	<xsl:template match="author" mode="findingaid">
		<!-- rico:hasCreator is an object property -->
		<!-- <rico:hasCreator xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:hasCreator>  -->
		<rico:hasCreator rdf:resource="{replace($AUTHOR_URI, $BASE_URI, '')}" />
	</xsl:template>
	
	<xsl:template match="publicationstmt" mode="#all">
		<xsl:apply-templates  mode="#current" />
	</xsl:template>
	<xsl:template match="publisher[normalize-space(.)]" mode="findingaid">
		<rico:hasPublisher rdf:resource="{replace($AUTHOR_URI, $BASE_URI, '')}" />
	</xsl:template>
	<xsl:template match="date[@normal]" mode="findingaid">		
		<xsl:choose>
			<xsl:when test="ead2rico:isDateRange(@normal)">
				<!-- Date range in @normal -->
				<rico:publicationDate><xsl:call-template name="outputDateFromDateRange"><xsl:with-param name="normal" select="@normal"/></xsl:call-template></rico:publicationDate>
				<!-- If the date spans multiple years, also output it as a Literal -->
				<xsl:if test="ead2rico:isDateRangeSpanningDifferentYears(@normal)">
					<rico:publicationDate xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:publicationDate>
				</xsl:if>
			</xsl:when>
			<xsl:when test="ead2rico:isDate(@normal)">
				<!-- Single date in @normal -->
				<rico:publicationDate><xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="@normal" /></xsl:call-template></rico:publicationDate>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template match="notestmt" mode="#all">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	<xsl:template match="note[normalize-space(.)]" mode="findingaid">
		<rico:descriptiveNote rdf:parseType="Literal"><html:p xml:lang="{$LITERAL_LANG}"><xsl:apply-templates select="p/node()" mode="html" /></html:p></rico:descriptiveNote>
	</xsl:template>
	
	<!-- ***** profiledesc processing ***** -->
	
	<xsl:template match="profiledesc" mode="#all">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	<xsl:template match="creation[normalize-space(.)]" mode="instantiation">
		<rico:history xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:history>
	</xsl:template>
	<xsl:template match="langusage" mode="findingaid">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	<xsl:template match="language[@langcode]" mode="findingaid">
		<rico:hasOrHadLanguage rdf:resource="{ead2rico:URI-Language(@langcode)}"/>
	</xsl:template>
	
	<!-- The rico:isOrWasRegulatedBy is inserted systematically on the FindingAid + its Instantiation -->
	<!--
	<xsl:template match="descrules[normalize-space(.)]" mode="instantiation">
		<rico:isOrWasRegulatedBy rdf:resource="rule/rl010"/>
	</xsl:template>
	<xsl:template match="descrules[normalize-space(.)]" mode="findingaid">
		Reference to ISAD(G), to be changed if you don't follow the ISAD(G) model
		<rico:isOrWasRegulatedBy rdf:resource="rule/rl009"/>
	</xsl:template>
	-->
	


	<!-- ***** revisiondesc processing ***** -->
	
	<xsl:template match="revisiondesc" mode="findingaid">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	<!-- Don't process change for which the item is empty -->
	<xsl:template match="change[item/text()]" mode="findingaid">
	  <rico:isOrWasAffectedBy>
         <rico:Activity>
            <rico:date>
            	<xsl:choose>
	            	<xsl:when test="ead2rico:isDateRange(date/@normal)">
						<xsl:call-template name="outputDateFromDateRange"><xsl:with-param name="normal" select="date/@normal"/></xsl:call-template>
					</xsl:when>
					<xsl:when test="ead2rico:isDate(date/@normal)">
						<xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="date/@normal"/></xsl:call-template>
					</xsl:when>
				</xsl:choose>
            </rico:date>
            <rico:descriptiveNote xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(item)" /></rico:descriptiveNote>
         </rico:Activity>
      </rico:isOrWasAffectedBy>
	</xsl:template>
	
	<!-- ***** archdesc processing ***** -->
	
	<xsl:template match="archdesc" mode="reference">
		<xsl:variable name="recordResourceId">
			<xsl:call-template name="recordResourceId">
				<xsl:with-param name="faId" select="$faId" />
				<xsl:with-param name="recordResourceId" />
			</xsl:call-template>
		</xsl:variable>	
	
		<rico:describesOrDescribed rdf:resource="{ead2rico:URI-RecordResource($recordResourceId)}" />
	</xsl:template>
	<xsl:template match="archdesc">
		<xsl:variable name="recordResourceId">
			<xsl:call-template name="recordResourceId">
				<xsl:with-param name="faId" select="$faId" />
				<xsl:with-param name="recordResourceId"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="instantiationId" select="concat($recordResourceId, '-i1')" />
	
		<!-- Generates the top RecordResource corresponding to the archdesc -->
		<rico:RecordResource rdf:about="{concat(ead2rico:URI-RecordResource($faId), '-')}">,
			<rico:isOrWasDescribedBy rdf:resource="{ead2rico:URI-FindingAid($faId)}" />
			
			<!--  dsc is processed later, outside of RecordResource. Note we process the element with a special mode to test on its type. -->
			<!--  Note that origination is still processed here to match inner persname/corpname/famname -->
			<!--  Note that originalsloc is still processed here to match inner ref -->
			<xsl:apply-templates select="." mode="level" />
			<xsl:apply-templates select="@otherlevel | (node() except (physdesc | dsc | daogrp | processinfo | appraisal | originalsloc[not(descendant::ref)]))" />

			<!-- process everything that needs to go inside a rico:history -->
			<xsl:variable name="historyContent">
				<xsl:apply-templates select="archdesc/bioghist" />
				<xsl:apply-templates select="processinfo" />
				<xsl:apply-templates select="appraisal" />
				<xsl:apply-templates select="did/origination" />
				<xsl:apply-templates select="originalsloc[not(descendant::ref)]" />
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="count($historyContent/*) > 1">
					<!-- if more than one children, encapsulate in a div -->
					<rico:history rdf:parseType="Literal">
						<html:div>
							<xsl:copy-of select="$historyContent" />
						</html:div>
					</rico:history>
				</xsl:when>
				<xsl:when test="count($historyContent/*) = 1">
					<rico:history rdf:parseType="Literal">
						<xsl:copy-of select="$historyContent" />
					</rico:history>
				</xsl:when>
			</xsl:choose>
			


			<!-- The instantiation of the RecordResource -->
			<rico:hasInstantiation>
				<rico:Instantiation rdf:about="{ead2rico:URI-Instantiation($instantiationId)}">
					<rico:isInstantiationOf rdf:resource="{ead2rico:URI-RecordResource($recordResourceId)}" />
					<!-- references to other digital copies -->
					<xsl:apply-templates select="daogrp | did/daogrp" mode="reference" />
					<!--  Recurse down. Note that origination is still processed here to match inner persname/corpname/famname -->
					<xsl:apply-templates select="node() except (daogrp | custodhist | acqinfo | processinfo | appraisal)" mode="instantiation" />
					<xsl:apply-templates select="physdesc" mode="instantiation" />
					<xsl:apply-templates select="physloc" mode="instantiation" />
					<xsl:apply-templates select="phystech" mode="instantiation" />
					<!-- everything that goes in the 'rico:history' section -->
					<xsl:variable name="instantiationHistoryContent">
						<!-- We want them in this order -->
						<xsl:apply-templates select="custodhist"  mode="instantiation" />
						<xsl:apply-templates select="acqinfo" mode="instantiation" />
						<xsl:apply-templates select="processinfo" mode="instantiation" />
						<xsl:apply-templates select="appraisal" mode="instantiation" />
						<xsl:apply-templates select="did/origination" mode="instantiation" />
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="count($instantiationHistoryContent/*) > 1">
							<!-- if more than one children, encapsulate in a div -->
							<rico:history rdf:parseType="Literal">
								<html:div>
									<xsl:copy-of select="$instantiationHistoryContent" />
								</html:div>
							</rico:history>
						</xsl:when>
						<xsl:when test="count($instantiationHistoryContent/*) = 1">
							<rico:history rdf:parseType="Literal">
								<xsl:copy-of select="$instantiationHistoryContent" />
							</rico:history>
						</xsl:when>
					</xsl:choose>
				</rico:Instantiation>
			</rico:hasInstantiation>			
						
			<!-- generates other Instantiations if any -->
			<xsl:apply-templates select="daogrp" />
			
			<!--  references to RecordResources, generates rico:includesOrIncluded -->
			<xsl:apply-templates select="dsc" mode="reference" />
		</rico:RecordResource>
		
		<!-- Recurse down in all RecordResources -->
		<xsl:apply-templates select="dsc" />
	</xsl:template>
	
	<xsl:template match="dsc" mode="#all">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	
	
	<!-- ***** c processing : generates corresponding RecordResource and Instantiation ***** -->

	<xsl:template match="c">

    <xsl:variable name="ancestorIds">
        <xsl:for-each select="ancestor::c">
            <xsl:value-of select="@id" />
            <xsl:text>-</xsl:text>
        </xsl:for-each>
    </xsl:variable>
    
	<xsl:variable name="recordResourceId" select="concat($faId, '-', $ancestorIds, @id)" />

    <xsl:variable name="instantiationId" select="concat($recordResourceId, '-i1')" />

    <xsl:variable name="parentRecordResourceId">
        <xsl:for-each select="ancestor::*[local-name() = 'c' or local-name() = 'archdesc'][1]">
            <xsl:variable name="ancestorIds">
                <xsl:for-each select="ancestor::c">
                    <xsl:value-of select="@id" />
                    <xsl:text>-</xsl:text>
                </xsl:for-each>
            </xsl:variable>
            <xsl:value-of select="concat($faId, '-', $ancestorIds, @id)" />
        </xsl:for-each>
    </xsl:variable>

	<xsl:variable name="ChildId" select="concat('person-', translate(child, ' ', '-'))" />
	<xsl:variable name="fatherId" select="concat('person-', translate(father, ' ', '-'))" />
	<xsl:variable name="motherId" select="concat('person-', translate(mother, ' ', '-'))" /> 
    <xsl:variable name="grandmother_fId" select="concat('person-', translate(grandmother_f, ' ', '-'))" /> 
    <xsl:variable name="grandmother_mId" select="concat('person-', translate(grandmother_m, ' ', '-'))" /> 
    <xsl:variable name="grandfather_fId" select="concat('person-', translate(grandfather_f, ' ', '-'))" />
    <xsl:variable name="grandfather_mId" select="concat('person-', translate(grandfather_m, ' ', '-'))" /> 
    <xsl:variable name="godfather_1Id" select="concat('person-', translate(godfather_1, ' ', '-'))" /> 
    <xsl:variable name="godfather_2Id" select="concat('person-', translate(godfather_2, ' ', '-'))" /> 
	<xsl:variable name="activityID" select="concat('bapt-of-', translate(child, ' ', '-'))"/>
	<xsl:variable name="eventID" select="concat('birth-of-', translate(child, ' ', '-'))"/>
	<xsl:variable name="activityDate" select="did/unitdate/@normal"/>
	<xsl:variable name="shortActivityDate" select="substring($activityDate, 1, 10)" />
	<xsl:variable name="activityDateID" select="concat('date', '-', translate($shortActivityDate, ' ', '-'))"/>
	
		<!-- RecordResource -->
		<rico:RecordResource rdf:about="{ead2rico:URI-RecordResource($recordResourceId)}">

			<!-- The inverse link to the parent depends on the incoming link, which depends on the type of the parent -->
			<xsl:choose>
				<xsl:when test="ead2rico:isRicoRecordSet(ancestor::*[local-name() = 'c' or local-name() = 'archdesc'][1])">
					<rico:isOrWasIncludedIn rdf:resource="{ead2rico:URI-RecordResource($parentRecordResourceId)}" />	
				</xsl:when>
				<xsl:when test="ead2rico:isRicoRecord(ancestor::*[local-name() = 'c' or local-name() = 'archdesc'][1])">
					<rico:isOrWasConstituentOf rdf:resource="{ead2rico:URI-RecordResource($parentRecordResourceId)}" />	
				</xsl:when>
				<xsl:otherwise>
					<rico:isOrWasPartOf rdf:resource="{ead2rico:URI-RecordResource($parentRecordResourceId)}" />					
				</xsl:otherwise>
			</xsl:choose>
						
			<!-- child c's and daogrp are processed after. Note that the current element is processed here with a special mode to determine its type -->
			<!--  Note that origination is still processed here to match inner persname/corpname/famname -->
			<!--  Note that originalsloc is still processed here to match inner ref -->
			<xsl:apply-templates select="." mode="level" />
			<xsl:apply-templates select="@otherlevel | (node() except (c | daogrp | processinfo | appraisal | originalsloc[not(descendant::ref)]))" />
			
			
			<!-- everything that goes in the 'rico:history' section -->
			<xsl:variable name="historyContent">
				<!-- We want them in this order -->
				<xsl:apply-templates select="processinfo" />
				<xsl:apply-templates select="appraisal" />
				<xsl:apply-templates select="did/origination" />
				<xsl:apply-templates select="originalsloc[not(descendant::ref)]" />
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="count($historyContent/*) > 1">
					<!-- if more than one children, encapsulate in a div -->
					<rico:history rdf:parseType="Literal">
						<html:div>
							<xsl:copy-of select="$historyContent" />
						</html:div>
					</rico:history>
				</xsl:when>
				<xsl:when test="count($historyContent/*) = 1">
					<rico:history rdf:parseType="Literal">
						<xsl:copy-of select="$historyContent" />
					</rico:history>
				</xsl:when>
			</xsl:choose>
			
			<!--  The instantiation of this RecordResource -->
			<rico:hasInstantiation>
				<rico:Instantiation rdf:about="{ead2rico:URI-Instantiation($instantiationId)}">
					<rico:isInstantiationOf rdf:resource="{ead2rico:URI-RecordResource($recordResourceId)}" />
					<!-- references to other digital copies -->
					<xsl:apply-templates select="daogrp | did/daogrp" mode="reference" />
					<!--  recurse down. Note that origination is still processed here to match inner persname/corpname/famname -->
					<xsl:apply-templates select="node() except (daogrp | custodhist | acqinfo | processinfo | appraisal)" mode="instantiation" />
					
					
					<!-- everything that goes in the 'rico:history' section -->
					<xsl:variable name="instantiationHistoryContent">
						<!-- We want them in this order -->
						<xsl:apply-templates select="custodhist"  mode="instantiation" />
						<xsl:apply-templates select="acqinfo" mode="instantiation" />
						<xsl:apply-templates select="processinfo" mode="instantiation" />
						<xsl:apply-templates select="appraisal" mode="instantiation" />
						<xsl:apply-templates select="did/origination" mode="instantiation" />
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="count($instantiationHistoryContent/*) > 1">
							<!-- if more than one children, encapsulate in a div -->
							<rico:history rdf:parseType="Literal">
								<html:div>
									<xsl:copy-of select="$instantiationHistoryContent" />
								</html:div>
							</rico:history>
						</xsl:when>
						<xsl:when test="count($instantiationHistoryContent/*) = 1">
							<rico:history rdf:parseType="Literal">
								<xsl:copy-of select="$instantiationHistoryContent" />
							</rico:history>
						</xsl:when>
					</xsl:choose>
				</rico:Instantiation>
			</rico:hasInstantiation>
			
	
			<xsl:if test="child">
				<xsl:variable name="effectiveBirthDate">
					<xsl:choose>
						<xsl:when test="formatted_birth_date">
							<xsl:value-of select="formatted_birth_date"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'não mencionado'"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="shortEffectiveBirthDate">
					<xsl:choose>
						<xsl:when test="$effectiveBirthDate = 'não mencionado'">
							<xsl:value-of select="$effectiveBirthDate"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="substring($effectiveBirthDate, 1, 10)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="birthDateId" select="concat('date-', translate($shortEffectiveBirthDate, ' ', '-'))"/>
				<xsl:variable name="isMotherKnown" select="mother != 'incógnita'" as="xs:boolean"/>
				<xsl:variable name="isFatherKnown" select="mother != 'incógnito'" as="xs:boolean"/>
				<rico:documents>
				<rico:Activity rdf:about="{$activityID}">
					<rico:hasActivityType rdf:resource="http://example.org/Baptism"/>
					<rico:label>Baptism of <xsl:value-of select="normalize-space(child)"/></rico:label>
					<rico:occurredAtDate>
						<rico:Date rdf:about="{$activityDateID}"></rico:Date>
					</rico:occurredAtDate>
					<rico:thingIsSourceOfRelation>
						<rico:PerformanceRelation rdf:about="{$ChildId}-performed-as-baptized">
							<rico:relationHasTarget>
								<person rdf:resource="{$ChildId}"/>
							</rico:relationHasTarget>
							<rico:relationHasContext>
								<rico:RoleType rdf:resource="http://example.org/BaptizedPerson"/>
							</rico:relationHasContext>
						</rico:PerformanceRelation>
					</rico:thingIsSourceOfRelation>
					<xsl:if test="godfather_1">
					<rico:thingIsSourceOfRelation>
						<rico:PerformanceRelation rdf:about="{$godfather_1Id}-performed-as-GodmotherOrGodfather">
							<rico:relationHasTarget>
                                <person rdf:resource="{$godfather_1Id}"/>
							</rico:relationHasTarget>
							<rico:relationHasContext>
								<rico:RoleType rdf:resource="http://example.org/GodmotherOrGodfather"/>
							</rico:relationHasContext>
						</rico:PerformanceRelation>
					</rico:thingIsSourceOfRelation>
                    </xsl:if>
					<xsl:if test="godfather_2">
					<rico:thingIsSourceOfRelation>
						<rico:PerformanceRelation rdf:about="{$godfather_2Id}-performed-as-GodmotherOrGodfather">
							<rico:relationHasTarget>
                                <person rdf:resource="{$godfather_2Id}"/>
							</rico:relationHasTarget>
							<rico:relationHasContext>
								<rico:RoleType rdf:resource="http://example.org/GodmotherOrGodfather"/>
							</rico:relationHasContext>
						</rico:PerformanceRelation>
					</rico:thingIsSourceOfRelation>
                    </xsl:if>

        		</rico:Activity>
				</rico:documents>
				<rico:isAssociatedWithEvent>
				<rico:Event rdf:about="{$eventID}">
					<rico:hasEventType rdf:resource="http://example.org/Birth"/>
					<rico:label>Birth of <xsl:value-of select="normalize-space(child)"/></rico:label>
					<rico:occurredAtDate>
						<rico:Date rdf:about="{$birthDateId}"></rico:Date>
					</rico:occurredAtDate>
					<rico:hasOrHadParticipant>
						<person rdf:resource="{$ChildId}"/>
					</rico:hasOrHadParticipant>
						<xsl:if test="$isMotherKnown">
							<rico:hasOrHadParticipant>
								<person rdf:resource="{$motherId}"/>
							</rico:hasOrHadParticipant>
						</xsl:if>
						<xsl:if test="$isFatherKnown">
							<rico:hasOrHadParticipant>
								<person rdf:resource="{$fatherId}"/>
							</rico:hasOrHadParticipant>
						</xsl:if>				
        		</rico:Event>
			</rico:isAssociatedWithEvent>
            <rico:isRelatedTo>
                <rico:person rdf:about="{$ChildId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(child)" />
                    </rico:name>
					<xsl:if test="birth_date">
						<rico:hasBirthDate>
							<rico:Date rdf:about="{$birthDateId}">
								<rico:expressedDate>
									<xs:string>
										<xsl:value-of select="normalize-space(birth_date)" />
									</xs:string>
								</rico:expressedDate>
								<xsl:if test="formatted_birth_date">
								<rico:normalizedDateValue>
									<xs:dateTime>
										<xsl:value-of select="normalize-space(formatted_birth_date)" />
									</xs:dateTime>
								</rico:normalizedDateValue>
								</xsl:if>
							</rico:Date>
						</rico:hasBirthDate>
					</xsl:if>
                    <xsl:if test="father">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$fatherId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
					<xsl:if test="mother">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$motherId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="father">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$fatherId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(father)" />
                    </rico:name>
					<xsl:if test="grandfather_f">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$grandfather_fId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
					<xsl:if test="grandmother_f">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$grandmother_fId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
					<xsl:if test="child">
                        <rico:hasChild>
                            <rico:person rdf:about="{$ChildId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="mother">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$motherId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(mother)" />
                    </rico:name>
					<xsl:if test="grandfather_m">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$grandfather_mId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
					<xsl:if test="grandmother_m">
                        <rico:isChildOf>
                            <rico:person rdf:about="{$grandmother_mId}"></rico:person>
                        </rico:isChildOf>
                    </xsl:if>
					<xsl:if test="child">
                        <rico:hasChild>
                            <rico:person rdf:about="{$ChildId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="grandfather_f">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$grandfather_fId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(grandfather_f)" />
                    </rico:name>
					<xsl:if test="father">
                        <rico:hasChild>
                            <rico:person rdf:about="{$fatherId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="grandfather_m">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$grandfather_mId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(grandfather_m)" />
                    </rico:name>
					<xsl:if test="father">
                        <rico:hasChild>
                            <rico:person rdf:about="{$fatherId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="grandmother_m">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$grandmother_mId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(grandmother_m)" />
                    </rico:name>
					<xsl:if test="mother">
                        <rico:hasChild>
                            <rico:person rdf:about="{$motherId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="grandmother_f">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$grandmother_fId}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(grandmother_f)" />
                    </rico:name>
					<xsl:if test="mother">
                        <rico:hasChild>
                            <rico:person rdf:about="{$motherId}"></rico:person>
                        </rico:hasChild>
                    </xsl:if>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="godfather_1">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$godfather_1Id}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(godfather_1)" />
                    </rico:name>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>

        <xsl:if test="godfather_2">
            <rico:isRelatedTo>
                <rico:person rdf:about="{$godfather_2Id}">
                    <rico:name>
                        <xsl:value-of select="normalize-space(godfather_2)" />
                    </rico:name>
                </rico:person>
            </rico:isRelatedTo>
        </xsl:if>




			<!-- generates other Instantiations -->
			<xsl:apply-templates select="daogrp" />
			
			<!-- children c's : generate includesOrIncluded/hasOrHadConstituent/hasOrHadPart recursively (contrary to first level archdesc) -->
			<!-- predicate depends on type of Record -->
			<xsl:variable name="currentC" select="." />
			<xsl:for-each select="c">
				<xsl:choose>
					<xsl:when test="ead2rico:isRicoRecordSet($currentC)">
						<rico:includesOrIncluded>
							<xsl:apply-templates select="." />
						</rico:includesOrIncluded>
					</xsl:when>
					<xsl:when test="ead2rico:isRicoRecord($currentC)">
						<rico:hasOrHadConstituent>
							<xsl:apply-templates select="." />
						</rico:hasOrHadConstituent>
					</xsl:when>
					<xsl:otherwise>
						<rico:hasOrHadPart>
							<xsl:apply-templates select="." />
						</rico:hasOrHadPart>
						<!--
						This is outputting a lot of messages, commenting for now
						<xsl:value-of select="ead2rico:warning($faId, 'UNKNOWN_RESOURCE_TYPE_OF_C', $currentC/@level)" />
						-->
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</rico:RecordResource>
	</xsl:template>


	<!-- ***** daogrp and daoloc processing : generates other Instantiations ***** -->

	<xsl:template match="daogrp" mode="reference">
		<xsl:variable name="recordResourceId">
			<xsl:call-template name="recordResourceId">
				<xsl:with-param name="faId" select="$faId" />
				<!-- Note how [last()] selects the nearest ancestor -->
				<xsl:with-param name="recordResourceId" select="(ancestor::*[self::c or self::archdesc])[last()]/@id" />
			</xsl:call-template>
		</xsl:variable>
		<!-- Add +2 to the offset of this daogrp element to build instantiation ID -->
		<xsl:variable name="instantiationId" select="concat($recordResourceId, '-i', count(preceding-sibling::daogrp)+2)" />
		<rico:hasDerivedInstantiation rdf:resource="{ead2rico:URI-Instantiation($instantiationId)}"/>
	</xsl:template>
	
	<xsl:template match="daogrp">

		<xsl:variable name="recordResourceId">
			<xsl:call-template name="recordResourceId">
				<xsl:with-param name="faId" select="$faId" />
				<!-- Note how [last()] selects the nearest ancestor -->
				<xsl:with-param name="recordResourceId" select="(ancestor::*[self::c or self::archdesc])[last()]/@id" />
			</xsl:call-template>
		</xsl:variable>
		<!-- Add +2 to the offset of this daogrp element to build instantiation ID -->
		<xsl:variable name="instantiationId" select="concat($recordResourceId, '-i', count(preceding-sibling::daogrp)+2)" />
		
		<!-- Inside this other Instantiation we only pick selected EAD elements, we don't reprocess all elements -->
		<rico:hasInstantiation>
			<rico:Instantiation rdf:about="{ead2rico:URI-Instantiation($instantiationId)}">
				<rico:isInstantiationOf rdf:resource="{ead2rico:URI-RecordResource($recordResourceId)}" />
				
				<!-- the image legend -->
				<xsl:apply-templates select="daodesc" />
				
				<!-- pick only the unittitle in the other Instantiations -->
				<!-- Finally, don't pick it :-) -->
				<!-- 
				<xsl:apply-templates select="(ancestor::*[self::c or self::archdesc])[last()]/did/unittitle" mode="instantiation" />
				-->
				
				<!-- pick also accessrestrict -->
				<xsl:apply-templates select="(ancestor::*[self::c or self::archdesc])[last()]/accessrestrict" mode="instantiation" />
				
				<!-- pick also userestrict -->
				<xsl:apply-templates select="(ancestor::*[self::c or self::archdesc])[last()]/userestrict" mode="instantiation" />
				
				<!-- pick also did/repository or did/unitid -->
				<xsl:apply-templates select="(ancestor::*[self::c or self::archdesc])[last()]/did/repository" mode="instantiation" />
				<xsl:apply-templates select="(ancestor::*[self::c or self::archdesc])[last()]/did/unitid" mode="instantiation" />
				
				<!-- We know it is a digital copy of the first instantiation -->
				<rico:isDerivedFromInstantiation rdf:resource="{ead2rico:URI-Instantiation(concat($recordResourceId, '-i1'))}"/>
				<rico:hasProductionTechniqueType rdf:resource="http://data.culture.fr/thesaurus/page/ark:/67717/a243a805-beb9-4f48-b537-18d1e11be48f"/>	
						
				<dc:format xml:lang="en">image/jpeg</dc:format>
				<!-- here the creator is by default the archival institution: it either produced the digital instantiation image by its own, or asked a private company to produce it and then got it and aggregated it into its own archives -->
                <rico:hasProvenance rdf:resource="{replace($AUTHOR_URI, $BASE_URI, '')}"/>
				
				<xsl:apply-templates select="daoloc" />
			</rico:Instantiation>
		</rico:hasInstantiation>

	</xsl:template>
	

	<xsl:template match="daodesc[child::node()]">
		<rico:descriptiveNote rdf:parseType="Literal">
			<xsl:choose>
				<xsl:when test="count(p) = 1">
					<html:p xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(p)" /></html:p>
				</xsl:when>
				<xsl:otherwise>
					<html:div xml:lang="{$LITERAL_LANG}">
						<xsl:apply-templates mode="html" />
					</html:div>
				</xsl:otherwise>
			</xsl:choose>
		</rico:descriptiveNote>
	</xsl:template>


	<!-- ***** scopecontent processing ***** -->
	
	<!-- need at least some non-empty content (commento precedente a modifica) -->
	<xsl:template match="scopecontent[normalize-space(.)]">
		<rico:scopeAndContent rdf:parseType="Literal">
			<html:div xml:lang="{$LITERAL_LANG}">
				<xsl:apply-templates mode="html" />
			</html:div>
		</rico:scopeAndContent>
	</xsl:template>

	<!-- ***** unitid processing for countrycode="PT" ***** -->
	<xsl:template match="unitid[@countrycode='PT'][normalize-space(.)]">
        <rico:hasOrHadIdentifier>
            <rico:Identifier rdf:about="reference-code-{.}">
                <rdfs:Literal>
                    <xsl:value-of select="normalize-space(.)" /> 
                </rdfs:Literal>
                <rico:hasIdentifierType>
                    <rico:IdentifierType rdf:about="ReferenceCode"/>
                </rico:hasIdentifierType>
            </rico:Identifier>
        </rico:hasOrHadIdentifier>
    </xsl:template>

	<!-- ***** odd processing con attributo original numeration ***** -->
	
	<xsl:template match="odd[@label='OriginalNumbering'][normalize-space(.)]">
        <rico:integrityNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
            	<html:p>
                    <html:span>Numeração original: </html:span>
                    <xsl:apply-templates mode="html" />
                </html:p>
            </html:div>
        </rico:integrityNote>
    </xsl:template>

    <!-- Template per <odd> senza attributo original numeration -->
    <xsl:template match="odd[not(@label='OriginalNumbering')][normalize-space(.)]">
        <rico:integrityNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
                <xsl:apply-templates mode="html" />
            </html:div>
        </rico:integrityNote>
    </xsl:template>

	<!-- ***** accessrestrict for archdesc/c and instantiation ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="accessrestrict[normalize-space(.)]" mode="#all">
		<rico:conditionsOfAccess rdf:parseType="Literal">
			<xsl:choose>
				<xsl:when test="count(p) = 1">
					<xsl:if test="normalize-space(p)">
						<html:p xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(p)" /></html:p>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<html:div xml:lang="{$LITERAL_LANG}">
						<xsl:apply-templates mode="html" />
					</html:div>
				</xsl:otherwise>
			</xsl:choose>
        </rico:conditionsOfAccess>
	</xsl:template>

	<!-- ***** userestrict for archdesc/c and instantiation ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="userestrict[normalize-space(.)]" mode="#all">
		<rico:conditionsOfUse rdf:parseType="Literal">
			<xsl:choose>
				<xsl:when test="count(p) = 1">
					<xsl:if test="normalize-space(p)">
						<html:p xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(p)" /></html:p>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<html:div xml:lang="{$LITERAL_LANG}">
						<xsl:apply-templates mode="html" />
					</html:div>
				</xsl:otherwise>
			</xsl:choose>
        </rico:conditionsOfUse>
	</xsl:template>
	
	<!-- arrangement for archdesc/c -->

	<!-- need at least some non-empty content  -->
	<xsl:template match="arrangement[normalize-space(.)]" mode="#all">
		<rico:structure rdf:parseType="Literal">
			<html:div xml:lang="{$LITERAL_LANG}">
				<xsl:apply-templates mode="html" />
			</html:div>
        </rico:structure>
	</xsl:template>

	<!-- ***** level processing on both c or archdesc ***** -->

	<xsl:template match="c | archdesc" mode="level">
		<xsl:choose>
			<xsl:when test="ead2rico:isRicoRecord(.)">
				<rdf:type rdf:resource="https://www.ica.org/standards/RiC/ontology#Record"/>
			</xsl:when>
			<xsl:when test="ead2rico:isRicoRecordSet(.)">
				<rdf:type rdf:resource="https://www.ica.org/standards/RiC/ontology#RecordSet"/>
			    <!-- 
				    RiC-O recordSetTypes :
				    
			        https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Collection
			        https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#File
			        https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Fonds
			        https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Series
		        -->
		        <xsl:choose>
		        	<xsl:when test="@level = 'fonds'">
		        		<rico:hasRecordSetType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Fonds"/>
		        	</xsl:when>
		        	<xsl:when test="@level = 'subfonds'">
		        		<!--  nothing -->
		        	</xsl:when>
		        	<xsl:when test="@level = 'series'">
		        		<rico:hasRecordSetType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Series"/>
		        	</xsl:when>
		        	<xsl:when test="@level = 'subseries'">
		        		<rico:hasRecordSetType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Series"/>
		        	</xsl:when>
		        	<xsl:when test="@level = 'recordgrp'">
		        		<!--  nothing -->
		        	</xsl:when>
		        	<xsl:when test="@level = 'subgrp'">
		        		<!--  nothing -->
		        	</xsl:when>
		        	<xsl:when test="@level = 'file'">
		        		<rico:hasRecordSetType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#File"/>
		        	</xsl:when>
		        	<xsl:when test="@level = 'collection'">
		        		<rico:hasRecordSetType rdf:resource="https://www.ica.org/standards/RiC/vocabularies/recordSetTypes#Collection"/>
		        	</xsl:when>
		        	<!--  'otherlevel' is already matched above -->
		        </xsl:choose>
			</xsl:when>
			<xsl:when test="ead2rico:isRicoRecordPart(.)">
				<rdf:type rdf:resource="https://www.ica.org/standards/RiC/ontology#RecordPart"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- nothing -->
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- ***** @otherlevel processing : this is used when determining the type in a function ***** -->
	<!-- ***** but we need to generate a dc:type + rico:type systematically ***** -->
	<xsl:template match="@otherlevel">
		<dc:type><xsl:value-of select="." /></dc:type>
		<rico:type><xsl:value-of select="." /></rico:type>
	</xsl:template>

	<!-- ***** custodhist / acqinfo processing for instantiation only ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="custodhist[normalize-space(.)]" mode="instantiation">	
		<html:div  xml:lang="{$LITERAL_LANG}">
            <html:h4>História da conservação</html:h4>
            <xsl:apply-templates mode="html" />
        </html:div>
	</xsl:template>

	<!-- need at least some non-empty content  -->
	<xsl:template match="acqinfo" mode="instantiation">
		<html:div  xml:lang="{$LITERAL_LANG}">
            <html:h4>Informações sobre os procedimentos de entrada</html:h4>
            <xsl:apply-templates mode="html" />
        </html:div>
	</xsl:template>

	<!-- ***** processinfo is for RecordResource also ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="processinfo[normalize-space(.)]" mode="#all">
		<html:div  xml:lang="{$LITERAL_LANG}">
            <html:h4>Informações sobre o tratamento</html:h4>
            <xsl:apply-templates mode="html" />
        </html:div>
	</xsl:template>

	<!-- ***** appraisal is for RecordResource also ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="appraisal[normalize-space(.)]" mode="#all">
		<html:div  xml:lang="{$LITERAL_LANG}">
            <html:h4>Informações sobre a avaliação</html:h4>
            <xsl:apply-templates mode="html" />
        </html:div>
	</xsl:template>
	
	<!-- ***** accruals ***** -->
	
	<!-- need at least some non-empty content  -->
	<xsl:template match="accruals[normalize-space(.)]">
		<rico:accrual rdf:parseType="Literal">
			<html:div xml:lang="{$LITERAL_LANG}">
	            <xsl:apply-templates mode="html" />
	        </html:div>
        </rico:accrual>
	</xsl:template>
	
	<!-- ***** otherfindaid ***** -->
	
	<xsl:template match="otherfindaid[list/item or p]">
		<rico:descriptiveNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
            	<html:h4>Outro(s) instrumento(s) de investigação</html:h4>
				<xsl:apply-templates mode="html" />
			</html:div>
		</rico:descriptiveNote>
		<!-- look for archref -->
		<xsl:apply-templates select="descendant::archref | descendant::extref" />
	</xsl:template>
	<xsl:template match="archref[ancestor::otherfindaid] | extref[ancestor::otherfindaid and ancestor::ref[@role='IR']]">
		<xsl:variable name="otherFaId">
			<!--  Extract everything before # if needed -->
			<xsl:value-of select="if(contains(@href, '#')) then substring-before(substring-after(@href, 'PT-ADPRT-'), '#') else substring-after(@href, 'PT-ADPRT-')" />
		</xsl:variable> 

		<!-- just make sure we don't output anything if FA id parsing fails -->		
		<xsl:if test="$otherFaId">
			<xsl:variable name="recordResourceId">
				<xsl:call-template name="recordResourceId">
					<xsl:with-param name="faId" select="$otherFaId" />
				</xsl:call-template>
			</xsl:variable>
			
			<xsl:variable name="recordResourceUri">
				<xsl:value-of select="ead2rico:URI-RecordResource($recordResourceId)" />
			</xsl:variable>
			<xsl:variable name="findingAidUri">
				<xsl:value-of select="ead2rico:URI-FindingAid($otherFaId)" />
			</xsl:variable>
			
			<rico:isRecordResourceAssociatedWithRecordResource rdf:resource="{$recordResourceUri}"/>
			<rico:isOrWasSubjectOf rdf:resource="{$findingAidUri}"/>
		</xsl:if>
	</xsl:template>


	<!-- ***** relatedmaterial ***** -->
	
	<xsl:template match="relatedmaterial[list/item or p]">
		<rico:descriptiveNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
            	<html:h4>Documento(s) relacionado(s)</html:h4>
				<xsl:apply-templates mode="html" />
			</html:div>
		</rico:descriptiveNote>
		<!-- look for archref -->
		<xsl:apply-templates select="descendant::archref" />
		<xsl:apply-templates select="descendant::extref" />
		<xsl:apply-templates select="descendant::ref" />
	</xsl:template>
	<!-- Surprinsingly the same template works for archref or extref or ref -->
	<xsl:template match="archref | extref[starts-with(@href, 'https://www.siv.archives-nationales.culture.gouv.fr/siv/IR/')] | ref[@role='WEB' and starts-with(@href, 'https://www.siv.archives-nationales.culture.gouv.fr/siv/IR/')]">
		<xsl:variable name="otherFaId">
			<!--  Extract everything before # if needed -->
			<xsl:value-of select="if(contains(@href, '#')) then substring-before(substring-after(@href, 'PT-ADPRT-'), '#') else substring-after(@href, 'PT-ADPRT-')" />
		</xsl:variable> 
		
		<xsl:variable name="recordResourceId">
			<xsl:call-template name="recordResourceId">
				<xsl:with-param name="faId" select="$otherFaId" />
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="recordResourceUri">
			<xsl:value-of select="ead2rico:URI-RecordResource($recordResourceId)" />
		</xsl:variable>
		
		<rico:isRecordResourceAssociatedWithRecordResource rdf:resource="{$recordResourceUri}"/>
	</xsl:template>
	
	
	<!-- ***** separatedmaterial ***** -->
	
	<xsl:template match="separatedmaterial[list/item or p]">
		<rico:descriptiveNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
            	<html:h4>Documento(s) separado(s)</html:h4>
				<xsl:apply-templates mode="html" />
			</html:div>
		</rico:descriptiveNote>
		<!-- look for archref -->
		<xsl:apply-templates select="descendant::archref" />
		<xsl:apply-templates select="descendant::extref" />
	</xsl:template>
	
	<!-- ***** did section ***** -->
	
	<xsl:template match="did" mode="#all">
		<!-- origination with text only is processed separately in archdesc or c templates -->
		<xsl:apply-templates select="* except origination" mode="#current" />
		<xsl:apply-templates select="origination/persname | origination/corpname | origination/famname" />
	</xsl:template>
	
	<!-- ***** did/unittitle for RecordResource and Instantiations ***** -->
	
	<xsl:template match="unittitle[normalize-space(.)]">
		<rico:title xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:title>
		<rdfs:label xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rdfs:label>
		<!--  Also searches for potential embedded unitdate -->
		<xsl:apply-templates select="unitdate" />
	</xsl:template>
	
	<xsl:template match="unittitle[normalize-space(.)]" mode="instantiation">
		<rico:title xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:title>
		<rdfs:label xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rdfs:label>
		<!--  Also searches for potential embedded unitdate -->
		<xsl:apply-templates select="unitdate" />
		<!-- Don't process embedded controlaccess tags -->
	</xsl:template>
	

<!--Date definition -->

<xsl:variable name="distinctDates" as="element()*">
    <xsl:for-each-group select="//unitdate" group-by="normalize-space(text())">
        <date key="{current-grouping-key()}"/>
    </xsl:for-each-group>
</xsl:variable>


<!-- Template principale -->
<xsl:template match="unitdate" mode="#all">
	<xsl:variable name="dateValue" select="normalize-space(unitdate)"/>
	<xsl:variable name="dateID" select="concat('date', '-', translate($dateValue, ' ', '-'))"/>
    <xsl:choose>
        <xsl:when test="@normal and text()">
            <!-- both @normal and text() are present -->
            <xsl:choose>
                <xsl:when test="ead2rico:isDateRange(@normal)">
                    <xsl:choose>
                        <xsl:when test="normalize-space(substring-before(@normal, '/')) = normalize-space(substring-after(@normal, '/'))">
                            <!-- single rico:Date if the begin and end date are the same -->
                            <xsl:variable name="singleDate" select="normalize-space(substring-before(@normal, '/'))"/>
                            <xsl:variable name="singleDateID" select="concat('date', '-', translate($singleDate, ' ', '-'))"/>
							<rico:hasCreationDate>
                            <rico:Date rdf:about="{$singleDateID}">
                                <xsl:call-template name="dateWithDatatype">
                                    <xsl:with-param name="text" select="$singleDate"/>
                                </xsl:call-template>
                                <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                                    <xsl:value-of select="normalize-space(string-join(text(), ' '))"/>
                                </rico:expressedDate>
								<rico:normalizedDateValue>
									<xs:dateTime>
										<xsl:value-of select="normalize-space(@normal)" />
									</xs:dateTime>
								</rico:normalizedDateValue>
								<rico:dateQualifier>
									<xs:string>Certain</xs:string>
								</rico:dateQualifier>
                            </rico:Date>
							</rico:hasCreationDate>
                        </xsl:when>
                        <xsl:otherwise>
                            <!-- Date range in @normal and a text() -->
                            <xsl:variable name="beginDate" select="normalize-space(substring-before(@normal, '/'))"/>
                            <xsl:variable name="beginDateID" select="concat('date', '-', translate($beginDate, ' ', '-'))"/>
                            <xsl:variable name="endDate" select="normalize-space(substring-after(@normal, '/'))"/>
                            <xsl:variable name="endDateID" select="concat('date', '-', translate($endDate, ' ', '-'))"/>
                            <rico:hasBeginningDate>
                                <rico:Date rdf:about="{$beginDateID}">
                                    <xsl:call-template name="dateWithDatatype">
                                        <xsl:with-param name="text" select="$beginDate"/>
                                    </xsl:call-template>
                                    <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                                        <xsl:value-of select="normalize-space(string-join(text(), ' '))"/>
                                    </rico:expressedDate>
                                </rico:Date>
                            </rico:hasBeginningDate>
                            <rico:hasEndDate>
                                <rico:Date rdf:about="{$endDateID}">
                                    <xsl:call-template name="dateWithDatatype">
                                        <xsl:with-param name="text" select="$endDate"/>
                                    </xsl:call-template>
                                    <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                                        <xsl:value-of select="normalize-space(string-join(text(), ' '))"/>
                                    </rico:expressedDate>
                                </rico:Date>
                            </rico:hasEndDate>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:when test="ead2rico:isDate(@normal)">
                    <!-- Single date in @normal and a text -->
                    <xsl:variable name="singleDate" select="@normal"/>
                    <xsl:variable name="singleDateID" select="concat('date', '-', translate($singleDate, ' ', '-'))"/>
					<rico:hasCreationDate>
                    <rico:Date rdf:about="{$singleDateID}">
                        <xsl:call-template name="dateWithDatatype">
                            <xsl:with-param name="text" select="$singleDate"/>
                        </xsl:call-template>
                        <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                            <xsl:value-of select="normalize-space(string-join(text(), ' '))"/>
                        </rico:expressedDate>
						<rico:normalizedDateValue>
							<xs:dateTime>
								<xsl:value-of select="normalize-space(@normal)" />
							</xs:dateTime>
						</rico:normalizedDateValue>
						<rico:dateQualifier>
							<xs:string>Certain</xs:string>
						</rico:dateQualifier>
                    </rico:Date>
				</rico:hasCreationDate>
                </xsl:when>
            </xsl:choose>
        </xsl:when>
        
        <xsl:when test="not(@normal) and text()">
            <!-- no @normal, but some text() -->
            <xsl:choose>
                <xsl:when test="ead2rico:isTextDateRange(text())">
                    <!-- Date range in text() -->
                    <xsl:variable name="beginDate" select="normalize-space(substring-before(text(), '-'))"/>
                    <xsl:variable name="beginDateID" select="concat('date', '-', translate($beginDate, ' ', '-'))"/>
                    <xsl:variable name="endDate" select="normalize-space(substring-after(text(), '-'))"/>
                    <xsl:variable name="endDateID" select="concat('date', '-', translate($endDate, ' ', '-'))"/>
                    <rico:hasBeginningDate>
                        <rico:Date rdf:about="{$beginDateID}">
                            <xsl:call-template name="dateWithDatatype">
                                <xsl:with-param name="text" select="$beginDate"/>
                            </xsl:call-template>
                            <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                                <xsl:value-of select="normalize-space(text())"/>
                            </rico:expressedDate>
                        </rico:Date>
                    </rico:hasBeginningDate>
                    <rico:hasEndDate>
                        <rico:Date rdf:about="{$endDateID}">
                            <xsl:call-template name="dateWithDatatype">
                                <xsl:with-param name="text" select="$endDate"/>
                            </xsl:call-template>
                            <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                                <xsl:value-of select="normalize-space(text())"/>
                            </rico:expressedDate>
                        </rico:Date>
                    </rico:hasEndDate>
                </xsl:when>
                <xsl:when test="ead2rico:isDate(text())">
                    <!-- Single date in text() -->
                    <xsl:variable name="singleDate" select="normalize-space(text())"/>
                    <xsl:variable name="singleDateID" select="concat('date', '-', translate($singleDate, ' ', '-'))"/>
                    <rico:hasCreationDate>
					<rico:Date rdf:about="{$singleDateID}">
                        <xsl:call-template name="dateWithDatatype">
                            <xsl:with-param name="text" select="$singleDate"/>
                        </xsl:call-template>
                        <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                            <xsl:value-of select="normalize-space(text())"/>
                        </rico:expressedDate>
							<rico:normalizedDateValue>
							<xs:dateTime>
								<xsl:value-of select="normalize-space(@normal)" />
							</xs:dateTime>
						</rico:normalizedDateValue>
						<rico:dateQualifier>
							<xs:string>Certain</xs:string>
						</rico:dateQualifier>
                    </rico:Date>
				</rico:hasCreationDate>
                </xsl:when>
                <xsl:otherwise>
				<rico:hasCreationDate>
                    <rico:Date rdf:about="{$dateID}">
                        <rico:expressedDate xml:lang="{$LITERAL_LANG}">
                            <xsl:value-of select="normalize-space(text())"/>
                        </rico:expressedDate>
						<rico:normalizedDateValue>
							<xs:dateTime>
								<xsl:value-of select="normalize-space(@normal)" />
							</xs:dateTime>
						</rico:normalizedDateValue>
						<rico:dateQualifier>
							<xs:string>Certain</xs:string>
						</rico:dateQualifier>
                    </rico:Date>
				</rico:hasCreationDate>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>

        <xsl:when test="not(@normal) and not(text())">
            <!-- empty unitdate : output nothing -->
        </xsl:when>        
    </xsl:choose>
</xsl:template>

	<!-- ***** did/langmaterial (only on RecordResource) ***** -->
	
        <xsl:template match="did/langmaterial">
        <xsl:variable name="lang" select="normalize-space(.)"/>
        <rico:hasOrHadLanguage>
            <rico:Language rdf:about="http://example.org/Portoguese">
                <rdfs:label>
                    <xsl:value-of select="$lang"/> 
                </rdfs:label>
            </rico:Language>
        </rico:hasOrHadLanguage>
    </xsl:template>

	<!--  ***** originalsloc (only for RecordResource) ***** -->

	<xsl:template match="originalsloc[not(descendant::ref)]">
		<xsl:if test="matches(normalize-space(.), '[A-Z]:\\.*')">
			<xsl:value-of select="ead2rico:warning($faId, 'ORIGINALSLOC_LOOKS_LIKE_A_FILE_PATH', normalize-space(.))" />
		</xsl:if>
		<html:div xml:lang="{$LITERAL_LANG}">
            <html:h4>Existência e local de armazenamento dos documentos originais</html:h4>
            <xsl:apply-templates mode="html" />
        </html:div>
	</xsl:template>

	<xsl:template match="originalsloc[descendant::ref]">
		<xsl:apply-templates select="descendant::ref" />
	</xsl:template>
	<xsl:template match="ref[ancestor::originalsloc]">
		<rico:hasGeneticLinkToRecordResource>
            <rico:RecordResource>
                <rico:title xml:lang="{$LITERAL_LANG}"><xsl:value-of select="normalize-space(.)" /></rico:title>
                <xsl:if test="extref/@href">
                	<rico:descriptiveNote xml:lang="{$LITERAL_LANG}">Lien : <xsl:value-of select="extref/@href" /></rico:descriptiveNote>
                </xsl:if>
                
            </rico:RecordResource>
        </rico:hasGeneticLinkToRecordResource>	
	</xsl:template>

	<!-- ***** controlaccess ***** -->

	<xsl:template match="controlaccess">
		<xsl:apply-templates mode="#current" />
	</xsl:template>
	
	<xsl:template match="genreform[@authfilenumber]">
		
		<xsl:choose>
			<xsl:when test="ead2rico:isRicoRecord(../..)">
				<xsl:choose>
					<!-- if provided genreform is a documentary form type, use corresponding property -->				
					<xsl:when test="ead2rico:isDocumentaryFormType(.)">
						<rico:hasDocumentaryFormType rdf:resource="{ead2rico:URI-DocumentaryFormType(@authfilenumber, @source)}"/>
					</xsl:when>
					<!-- if provided genreform is a record state, use corresponding property -->				
					<xsl:when test="ead2rico:isRecordState(.)">
						<rico:hasRecordState rdf:resource="{ead2rico:URI-RecordState(@authfilenumber, @source)}"/>
					</xsl:when>
					<xsl:otherwise>
						<!-- Output a default property and generate a warning -->
						<dc:type><xsl:value-of select="text()" /></dc:type>
						<rico:type><xsl:value-of select="text()" /></rico:type>
						<xsl:value-of select="ead2rico:warning($faId, 'UNKNOWN_GENREFORM', @authfilenumber)" />
					</xsl:otherwise>
				</xsl:choose>				
			</xsl:when>
			<xsl:when test="ead2rico:isRicoRecordSet(../..)">

				<xsl:choose>
					<!-- if provided genreform is a documentary form type, use corresponding property -->				
					<xsl:when test="ead2rico:isDocumentaryFormType(.)">
						<!-- someMembers property as we are not sure all children have the same dft -->
						<rico:hasOrHadSomeMembersWithDocumentaryFormType rdf:resource="{ead2rico:URI-DocumentaryFormType(@authfilenumber, @source)}"/>
					</xsl:when>
					<!-- if provided genreform is a record set type, use corresponding property -->				
					<xsl:when test="ead2rico:isRecordSetType(.)">
						<rico:hasRecordSetType rdf:resource="{ead2rico:URI-RecordSetType(@authfilenumber, @source)}"/>
					</xsl:when>
					<!-- if provided genreform is a record state, use corresponding property -->				
					<xsl:when test="ead2rico:isRecordState(.)">
						<rico:hasOrHadSomeMembersWithRecordState rdf:resource="{ead2rico:URI-RecordState(@authfilenumber, @source)}"/>
					</xsl:when>
					<xsl:otherwise>
						<!-- Output a default property and generate a warning -->
						<dc:type><xsl:value-of select="text()" /></dc:type>
						<rico:type><xsl:value-of select="text()" /></rico:type>
						<xsl:value-of select="ead2rico:warning($faId, 'UNKNOWN_GENREFORM', @authfilenumber)" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<!-- we don't know if this is a Record or a RecordSet. Output a generic dc:type property -->
				<dc:type><xsl:value-of select="text()" /></dc:type>
				<rico:type><xsl:value-of select="text()" /></rico:type>
				<xsl:value-of select="ead2rico:warning($faId, 'UNKNOWN_RESOURCE_TYPE_IN_GENREFORM', ../../@level)" />
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	

	<!-- ***** physdesc ***** -->

		<!-- ***** did/physdesc (only on RecordResource) ***** -->
	
    <xsl:template match="physdesc">
    </xsl:template>	

	<xsl:template match="phystech">
    </xsl:template>	
	
	<xsl:template match="physfacet[@type = 'd3nd9y3c6o-iu0j3xsmoisx' or @type = 'd3nd9xpopj-ckdrv6ljeqeg']" mode="instantiation">
		<rico:hasRepresentationType rdf:resource="{ead2rico:URI-RepresentationOrCarrierType(@type, @source)}"/>   
	</xsl:template>
	<xsl:template match="physfacet[not(@type = 'd3nd9y3c6o-iu0j3xsmoisx' or @type = 'd3nd9xpopj-ckdrv6ljeqeg')]" mode="instantiation">
		<rico:hasCarrierType rdf:resource="{ead2rico:URI-RepresentationOrCarrierType(@type, @source)}"/>   
	</xsl:template>

	<!--  ***** altformavail ***** -->
	
	<xsl:template match="altformavail" >
		<rico:descriptiveNote rdf:parseType="Literal">
			<html:div xml:lang="{$LITERAL_LANG}">
				<html:h4>Documentos de substituição</html:h4>
				<xsl:apply-templates mode="html" />
			</html:div>
       </rico:descriptiveNote>
	</xsl:template>
	
	
	<!--  ***** bibliography ***** -->
	
	<xsl:template match="bibliography[normalize-space(.)]">
		<rico:descriptiveNote rdf:parseType="Literal">
			<html:div xml:lang="{$LITERAL_LANG}">
				<html:h4>Bibliografia</html:h4>
				<xsl:apply-templates mode="html" />
			</html:div>
       </rico:descriptiveNote>
	</xsl:template>

	<xsl:output method="xml" indent="yes"/>

    <!-- Regola generale per copiare il resto del contenuto XML -->
    <xsl:template match="node()|@*">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
    </xsl:template>

	<!-- ***** Processing of formatting elements p, list, item, span ***** -->
	
	<xsl:template match="p[normalize-space(.)]" mode="html">
		<xsl:choose>
			<!-- If p contains a ref and only refs... -->
			<xsl:when test="ref and not(*[local-name(.) != 'ref']) and not(text()[normalize-space()])">
				<!-- it is ignored, the refs below will generate their own p -->
				<xsl:apply-templates mode="html" />
			</xsl:when>
			<!-- if we have a list inside a p -->
			<xsl:when test="list">
				<xsl:for-each select="*|text()">
					<xsl:choose>
						<!-- Then put all text of that list in a paragraph before the list -->
						<xsl:when test=". instance of text()">
							<html:p><xsl:apply-templates mode="html" select="." /></html:p>
						</xsl:when>
						<!-- Then output the list -->
						<xsl:otherwise>
							<xsl:apply-templates mode="html" select="." />
						</xsl:otherwise>
					</xsl:choose>					
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<html:p><xsl:apply-templates mode="html" /></html:p>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	<xsl:template match="emph[@render = 'super']" mode="html">
		<html:sup><xsl:apply-templates mode="html" /></html:sup>
	</xsl:template>
	<xsl:template match="emph[@render = 'sub']" mode="html">
		<html:sub><xsl:apply-templates mode="html" /></html:sub>
	</xsl:template>
	<xsl:template match="emph[@render = 'italic']" mode="html">
		<html:i><xsl:apply-templates mode="html" /></html:i>
	</xsl:template>
	<xsl:template match="emph[@render = 'bold']" mode="html">
		<html:b><xsl:apply-templates mode="html" /></html:b>
	</xsl:template>
	<xsl:template match="emph[@render = 'underline']" mode="html">
		<html:u><xsl:apply-templates mode="html" /></html:u>
	</xsl:template>
	<xsl:template match="list" mode="html">
		<html:ul><xsl:apply-templates mode="html" /></html:ul>
	</xsl:template>
	<xsl:template match="list/text()" mode="html"><xsl:value-of select="normalize-space(.)" /></xsl:template>
	<xsl:template match="item" mode="html">
		<html:li><xsl:apply-templates mode="html" /></html:li>
	</xsl:template>
	<xsl:template match="lb" mode="html">
		<html:br />
	</xsl:template>
	<!-- Note how the extra space is preserved within mixed-content, at beginning or end -->
	<xsl:template match="text()" mode="html"><xsl:if test="starts-with(., ' ') and not(position() = 1)"><xsl:value-of select="' '" /></xsl:if><xsl:value-of select="normalize-space(.)" /><xsl:if test="ends-with(., ' ') and not(position() = last())"><xsl:value-of select="' '" /></xsl:if></xsl:template>
	<!-- These are only for the bibliography, or scopecontent -->
	<xsl:template match="head" mode="html">
		<html:h5><xsl:value-of select="normalize-space(.)" /></html:h5>
	</xsl:template>
	<xsl:template match="title" mode="html">
		<html:cite><xsl:apply-templates mode="html" /></html:cite>
	</xsl:template>
	<xsl:template match="date" mode="html">
		<html:time><xsl:apply-templates mode="html" /></html:time>
	</xsl:template>
	<!-- inner scopecontent generate div -->
	<xsl:template match="scopecontent" mode="html">
		<html:div>
			<xsl:apply-templates mode="html" />
		</html:div>
	</xsl:template>
	
	<!-- a ref that is under a p that contains only refs -->
	<xsl:template match="ref[parent::p[ref and not(*[local-name(.) != 'ref']) and not(text()[normalize-space()]) ]]" mode="html">
		<html:p><xsl:apply-templates mode="html" /></html:p>
	</xsl:template>
	<xsl:template match="ref[@role='WEB' and starts-with(@href, 'https://www.siv.archives-nationales.culture.gouv.fr/siv/IR/')]" mode="html">
		<html:p><html:a href="{@href}"><xsl:apply-templates mode="html" /></html:a></html:p>
	</xsl:template>
	<!-- a normal ref not under a p with only refs -->
	<xsl:template match="ref" mode="html">
		<xsl:apply-templates mode="html" />
	</xsl:template>
	<xsl:template match="archref | extref[ancestor::ref[@role = 'IR']]" mode="html">
		<xsl:variable name="href" select="ead2rico:URL-IRorUD(@href)" />
		<xsl:choose>
			<xsl:when test="not(contains($href, ' '))">
				<html:a href="{$href}"><xsl:apply-templates mode="html" /></html:a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates mode="html" />
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	<xsl:template match="extref[ancestor::ref[@role = 'web' or @role = 'WEB' or @role = 'ANX' or @role='anx']]" mode="html">
		<!--  we resolve relative links to a base URL -->
		<xsl:variable name="href" select="
			if(not(starts-with(@href, 'http'))) then 
				concat($BASE_URL_FOR_RELATIVE_LINKS, @href)
			else 
				@href" />
		<xsl:choose>
			<xsl:when test="not(contains($href, ' '))">
				<html:a href="{if(ends-with($href,'.')) then substring($href, 1, string-length($href)-1) else $href}"><xsl:apply-templates mode="html" /></html:a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates mode="html" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ***** Date ***** -->
		
	<!-- Output a date value with the proper datatype based on the date format -->
	<xsl:template name="outputDateFromDateRange">
        <xsl:param name="normal"/>
        
        <xsl:variable name="begin" select="normalize-space(substring-before($normal, '/'))" />
        <xsl:variable name="end" select="normalize-space(substring-after($normal, '/'))" />

		<xsl:variable name="beginYearMonth" select="normalize-space(substring($begin, 1, 7))" />
		<xsl:variable name="endYearMonth" select="normalize-space(substring($end, 1, 7))" />
		
		<xsl:variable name="beginYear" select="normalize-space(substring-before($beginYearMonth, '-'))" />
		<xsl:variable name="endYear" select="normalize-space(substring-before($endYearMonth, '-'))" />
		
<!-- 		<xsl:message><xsl:value-of select="concat($begin, ' vs. ', $end,', ', $beginYearMonth, ' vs. ', $endYearMonth, ', ', $beginYear, ' vs. ', $endYear)" /></xsl:message> -->
		
		<xsl:choose>
			<xsl:when test="$begin = $end">
				<xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="$begin" /></xsl:call-template>
			</xsl:when>
			<xsl:when test="($begin != $end) and ($beginYearMonth = $endYearMonth)">
				<xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="$beginYearMonth" /></xsl:call-template>
			</xsl:when>
			<xsl:when test="($begin != $end) and ($beginYearMonth != $endYearMonth) and ($beginYear = $endYear)">
				<xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="$beginYear" /></xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="dateWithDatatype"><xsl:with-param name="text" select="normalize-space($begin)" /></xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
		
	<!-- Tests if a c or archdesc element corresponds to a Record -->
	<xsl:function name="ead2rico:isRicoRecord" as="xs:boolean">
		<xsl:param name="cOrArchdesc"/>
		<xsl:sequence select="$cOrArchdesc/@level = 'item'"/>  
	</xsl:function>

	<!-- Tests if a c or archdesc element corresponds to a RecordSet -->
	<xsl:function name="ead2rico:isRicoRecordSet" as="xs:boolean">
		<xsl:param name="cOrArchdesc"/>

		<!-- if archdesc without an explicit level, consider it a RecordSet -->
		<xsl:sequence select="
			(local-name($cOrArchdesc) = 'archdesc' and not($cOrArchdesc/@level))
			or
			(
				$cOrArchdesc/@level
				and
				$cOrArchdesc/@level != 'item'
				and
				(
					$cOrArchdesc/@level != 'otherlevel'
					or
					matches($cOrArchdesc/@otherlevel,$OTHERLEVEL_RECORDSET_PATTERN)
				)
			)
		"/>  
	</xsl:function>

	<!-- Tests if a c or archdesc element corresponds to a RecordPart -->
	<xsl:function name="ead2rico:isRicoRecordPart" as="xs:boolean">
		<xsl:param name="cOrArchdesc"/>

		<!-- if archdesc without an explicit level, consider it a RecordSet -->
		<xsl:sequence select="
			$cOrArchdesc/@level = 'otherlevel'
			and
			$cOrArchdesc/@otherlevel
			and
			matches($cOrArchdesc/@otherlevel,$OTHERLEVEL_RECORDPART_PATTERN)
		"/>  
	</xsl:function>

		
	<xsl:function name="ead2rico:isDateRange" as="xs:boolean">
		<xsl:param name="text"/>
		<xsl:sequence select="
			contains($text, '/')
			and
			ead2rico:isDate(normalize-space(substring-before($text, '/')))
			and
			ead2rico:isDate(normalize-space(substring-after($text, '/')))
		"/>  
	</xsl:function>
	
	<xsl:function name="ead2rico:isTextDateRange" as="xs:boolean">
		<xsl:param name="text"/>
		<xsl:sequence select="
			contains($text, '-')
			and
			ead2rico:isDate(normalize-space(substring-before($text, '-')))
			and
			ead2rico:isDate(normalize-space(substring-after($text, '-')))
		"/>  
	</xsl:function>
	
	<xsl:function name="ead2rico:isDate" as="xs:boolean">
		<xsl:param name="text"/>
		<xsl:sequence select="
				matches($text,'^[0-9][0-9][0-9][0-9]$')
				or
				matches($text,'^[0-9][0-9][0-9][0-9]-[0-9][0-9]$')
				or
				matches($text,'^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]$')
		"/>  
	</xsl:function>
	
	<xsl:function name="ead2rico:isDateRangeSpanningDifferentYears" as="xs:boolean">
		<xsl:param name="normal"/>
        
        <xsl:variable name="begin" select="normalize-space(substring-before($normal, '/'))" />
        <xsl:variable name="end" select="normalize-space(substring-after($normal, '/'))" />

		<xsl:variable name="beginYearMonth" select="normalize-space(substring($begin, 1, 7))" />
		<xsl:variable name="endYearMonth" select="normalize-space(substring($end, 1, 7))" />
		
		<xsl:variable name="beginYear" select="normalize-space(substring-before($beginYearMonth, '-'))" />
		<xsl:variable name="endYear" select="normalize-space(substring-before($endYearMonth, '-'))" />
		
		<xsl:sequence select="$beginYear != $endYear" />
	</xsl:function>
	
	<!-- Output a date value with the proper datatype based on the date format -->
	<xsl:template name="dateWithDatatype">
        <xsl:param name="text"/>

		<xsl:choose>
			<xsl:when test="matches($text,'^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]$')">
				<xsl:attribute name="rdf:datatype">
                    <xsl:text>http://www.w3.org/2001/XMLSchema#date</xsl:text>
                </xsl:attribute>
                <xsl:value-of select="normalize-space($text)"/>
			</xsl:when>
			<xsl:when test="matches($text,'^[0-9][0-9][0-9][0-9]-[0-9][0-9]$')">
				<xsl:attribute name="rdf:datatype">
                    <xsl:text>http://www.w3.org/2001/XMLSchema#gYearMonth</xsl:text>
                </xsl:attribute>
                <xsl:value-of select="normalize-space($text)"/>
			</xsl:when>
			<xsl:when test="matches($text,'^[0-9][0-9][0-9][0-9]$')">
				<xsl:attribute name="rdf:datatype">
                    <xsl:text>http://www.w3.org/2001/XMLSchema#gYear</xsl:text>
                </xsl:attribute>
                <xsl:value-of select="normalize-space($text)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space($text)"/>
			</xsl:otherwise>
		</xsl:choose>
    </xsl:template>

    <!-- Template per matchare <scopecontent> -->
    <xsl:template match="scopecontent">
        <xsl:copy>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>

    <!-- Template per matchare <odd> con contenuto non vuoto e attributo label="OriginalNumbering" -->
    <xsl:template match="odd[@label='OriginalNumbering'][normalize-space(.)]">
        <rico:integrityNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
                <html:p>
                    <html:span>Numeração original: </html:span>
                    <xsl:apply-templates mode="html" />
                </html:p>
            </html:div>
        </rico:integrityNote>
    </xsl:template>

    <!-- Template per matchare gli altri <odd> con contenuto non vuoto -->
    <xsl:template match="odd[not(@label='OriginalNumbering')][normalize-space(.)]">
        <rico:integrityNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
                <html:p>
                    <xsl:apply-templates mode="html" />
                </html:p>
            </html:div>
        </rico:integrityNote>
    </xsl:template>

    <!-- Template in modalità html per i figli di <odd> -->
    <xsl:template match="*" mode="html">
        <xsl:copy>
            <xsl:apply-templates select="@* | node()" />
        </xsl:copy>
    </xsl:template>

    <!-- Regola generale per copiare il resto del contenuto XML -->
    <xsl:template match="node()|@*">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
    </xsl:template>

	<!-- Template to transform <physloc> tag -->
	<xsl:template match="physloc">
    </xsl:template>

	<xsl:template match="child">
    </xsl:template>

	<xsl:template match="father">
    </xsl:template>

		<xsl:template match="mother">
    </xsl:template>

	<xsl:template match="grandmother_m">
    </xsl:template>
	<xsl:template match="grandmother_f">
    </xsl:template>
	<xsl:template match="grandfather_f">
    </xsl:template>
	<xsl:template match="grandfather_m">
    </xsl:template>
		<xsl:template match="godfather_1">
    </xsl:template>
		<xsl:template match="godfather_2">
    </xsl:template>

	<xsl:template match="birth_date">
    </xsl:template>

	<xsl:template match="formatted_birth_date">
    </xsl:template>


	<!-- Template to transform <phystec> tag -->
	<xsl:template match="phystech" mode="instantiation">
		<rico:physicalCharacteristicNote rdf:parseType="Literal">
            <html:div xml:lang="{$LITERAL_LANG}">
                <html:p>
                    <xsl:apply-templates mode="html" />
                </html:p>
            </html:div>
        </rico:physicalCharacteristicNote>
    </xsl:template>

	 <xsl:template match="physloc" mode="instantiation">
        <rico:hasOrHadIdentifier>
            <rico:Identifier rdf:about="physical-location-{translate(., ' ', '-')}">
                <rico:textualValue>
                    <xsl:value-of select="normalize-space(.)"/>
                </rico:textualValue>
                <rico:hasIdentifierType>
                    <rico:IdentifierType rdf:about="PhysicalLocation"/>
                </rico:hasIdentifierType>
            </rico:Identifier>
        </rico:hasOrHadIdentifier>
    </xsl:template>

	<xsl:template match="physdesc" mode="instantiation">
			<xsl:if test="dimensions and contains(dimensions, 'mm')">
            <rico:hasExtent>
				<rico:CarrierExtent rdf:about="{concat('carrier-extent-', substring(dimensions, 0, 10))}">
                <rico:textualValue>
                    <xsl:value-of select="dimensions"/>
                </rico:textualValue>
                <rico:hasUnitOfMeasurement>
                        <rico:UnitOfMeasurement rdf:resource="http://example.org/Millimeters"/>
                </rico:hasUnitOfMeasurement>
				</rico:CarrierExtent>
            </rico:hasExtent>
            </xsl:if>
			<xsl:if test="dimensions and contains(dimensions, 'ml')">
            <rico:hasExtent>
				<rico:CarrierExtent rdf:about="{concat('carrier-extent-', substring(dimensions, 0, 10))}">
					<rico:textualValue>
						<xsl:value-of select="dimensions"/>
					</rico:textualValue>
					<rico:hasUnitOfMeasurement>
							<rico:UnitOfMeasurement rdf:about="http://example.org/LinearMeters"/>
					</rico:hasUnitOfMeasurement>
				</rico:CarrierExtent>
            </rico:hasExtent>
            </xsl:if>
			<xsl:if test="dimensions and contains(dimensions, 'cm')">
            <rico:hasExtent>
				<rico:CarrierExtent rdf:about="{concat('carrier-extent-', substring(dimensions, 0, 10))}">
					<rico:textualValue>
						<xsl:value-of select="dimensions"/>
					</rico:textualValue>
					<rico:hasUnitOfMeasurement>
							<rico:UnitOfMeasurement rdf:about="http://example.org/Centimeters"/>
					</rico:hasUnitOfMeasurement>
				</rico:CarrierExtent>
            </rico:hasExtent>
            </xsl:if>
            <xsl:if test="extent">

                <rico:hasExtent>
				<rico:InstantiationExtent rdf:about="{concat('instantiation-extent', extent, '-books')}">
                    <rico:textualValue>
                        <xsl:value-of select="extent"/>
                    </rico:textualValue>
                    <rico:hasExtentType>
                        <rico:CarrierExtent rdf:about="http://example.org/Books"/>
                    </rico:hasExtentType>
				</rico:InstantiationExtent>
                </rico:hasExtent>
            </xsl:if>
            <xsl:if test="dimensions and contains(dimensions, 'papel')">
                <rico:hasCarrierType>
                    <rico:CarrierType rdf:about="http://example.org/Papel"/>
                </rico:hasCarrierType>
            </xsl:if>
		</xsl:template>



	<xsl:template match="archdesc[@level='fonds']/did/repository">
        <rico:hasOrHadHolder>
            <rico:CorporateBody>
                <rico:name>
                    <xsl:value-of select="normalize-space(.)"/>
                </rico:name>
            </rico:CorporateBody>
        </rico:hasOrHadHolder>
    </xsl:template>

	<xsl:template match="c/did/repository" priority="2" />


</xsl:stylesheet>